[PATCH 2/2] Show correct status for no %packages with selected environment (#1261393)

Martin Kolman mkolman at redhat.com
Tue Sep 15 14:57:54 UTC 2015


Show correct spoke status when an environment has been manually selected but
there is no %packages section kickstart.

Otherwise the software spoke would always show "Nothing selected" even
after the users selects an environment.

Related: rhbz#1261393
Signed-off-by: Martin Kolman <mkolman at redhat.com>
---
 pyanaconda/ui/gui/spokes/software.py | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/pyanaconda/ui/gui/spokes/software.py b/pyanaconda/ui/gui/spokes/software.py
index e1b2579..54fa8e7 100644
--- a/pyanaconda/ui/gui/spokes/software.py
+++ b/pyanaconda/ui/gui/spokes/software.py
@@ -278,8 +278,8 @@ class SoftwareSelectionSpoke(NormalSpoke):
                 # environment is set to an invalid value
                 elif not self.environment_valid:
                     return _("Invalid environment specified in kickstart")
-            # we have no packages section in the kickstart
-            else:
+            # we have no packages section in the kickstart and no environment is selected
+            elif not self.environment:
                 return _("Nothing selected")
         else:
             if not self.environment_valid:
-- 
2.4.3



More information about the anaconda-patches mailing list